@@ -11,13 +11,20 @@ class OcrProduct:
     def __init__(self,
                  image,
                  language: str = 'por',
+                 spell_corrector=False,
                  show_performace: bool = False):
-        self.define_global_vars(language, show_performace)
+        self.define_global_vars(language, show_performace, spell_corrector)
         started_time = time()
 
         input_type = aux.get_input_type(image)
         self.text = self.process_image(image, input_type)
 
+        if self.spell_corrector:
+            sym_spell = aux.load_dict_to_memory()
+            self.text = [aux.get_word_suggestion(
+                sym_spell, input_term) for input_term in self.text.split(' ')]
+            self.text = ' '.join(self.text)
+
         self.execution_time = time() - started_time
 
     def __repr__(self):
@@ -25,13 +32,15 @@ class OcrProduct:
             if not self.show_performace \
             else repr([self.text, self.show_performace])
 
-    def define_global_vars(self, language, show_performace):
-        if isinstance(language, str) and isinstance(show_performace, bool):
+    def define_global_vars(self, language, show_performace, spell_corrector):
+        if isinstance(language, str) and isinstance(show_performace, bool) \
+                and isinstance(spell_corrector, bool):
             self.lang = language
             self.show_performace = show_performace
+            self.spell_corrector = spell_corrector
         else:
             raise TypeError(
-                'language variable must need be a string and show_perf. bool!')
+                'language variable must be a string, show_perf. and spell_corrector bool!')
 
     def process_image(self, image, _type):
         if _type == 1:
